@@ -1,10 +1,20 @@
 #' Check suitability of data for clustering
 #'
-#' This checks whether the data is appropriate for clustering using the Hopkins' H statistic of given data. If the value of Hopkins statistic is close to 0 (below 0.5), then we can reject the null hypothesis and conclude that the dataset is significantly clusterable. A value for H lower than 0.25 indicates a clustering tendency at the 90\% confidence level. The visual assessment of cluster tendency (VAT) approach (Bezdek and Hathaway, 2002) consists in investigating the heatmap of the ordered dissimilarity matrix. Following this, one can potentially detect the clustering tendency by counting the number of square shaped blocks along the diagonal.
+#' This checks whether the data is appropriate for clustering using the Hopkins'
+#' H statistic of given data. If the value of Hopkins statistic is close to 0
+#' (below 0.5), then we can reject the null hypothesis and conclude that the
+#' dataset is significantly clusterable. A value for H lower than 0.25 indicates
+#' a clustering tendency at the `90%` confidence level. The visual assessment of
+#' cluster tendency (VAT) approach (Bezdek and Hathaway, 2002) consists in
+#' investigating the heatmap of the ordered dissimilarity matrix. Following
+#' this, one can potentially detect the clustering tendency by counting the
+#' number of square shaped blocks along the diagonal.
 #'
 #' @param x A data frame.
 #' @param standardize Standardize the dataframe before clustering (default).
-#' @param distance Distance method used. Other methods than "euclidean" (default) are exploratory in the context of clustering tendency. See \code{\link[stats:dist]{dist()}} for list of available methods.
+#' @param distance Distance method used. Other methods than "euclidean"
+#'   (default) are exploratory in the context of clustering tendency. See
+#'   [stats::dist()] for list of available methods.
 #' @param ... Arguments passed to or from other methods.
 #'
 #' @examples
@@ -15,14 +25,21 @@
 #' }
 #' @return The H statistic (numeric)
 #'
-#' @seealso \code{\link{check_kmo}}, \code{\link{check_sphericity}} and \code{\link{check_factorstructure}}.
+#' @seealso [check_kmo()], [check_sphericity_bartlett()] and [check_factorstructure()].
 #'
-#' @references \itemize{
-#'   \item Lawson, R. G., & Jurs, P. C. (1990). New index for clustering tendency and its application to chemical problems. Journal of chemical information and computer sciences, 30(1), 36-41.
-#'   \item Bezdek, J. C., & Hathaway, R. J. (2002, May). VAT: A tool for visual assessment of (cluster) tendency. In Proceedings of the 2002 International Joint Conference on Neural Networks. IJCNN02 (3), 2225-2230. IEEE.
-#' }
+#' @references
+#' - Lawson, R. G., & Jurs, P. C. (1990). New index for clustering
+#'   tendency and its application to chemical problems. Journal of chemical
+#'   information and computer sciences, 30(1), 36-41.
+#'
+#' - Bezdek, J. C., & Hathaway, R. J. (2002, May). VAT: A tool for visual
+#'   assessment of (cluster) tendency. In Proceedings of the 2002 International
+#'   Joint Conference on Neural Networks. IJCNN02 (3), 2225-2230. IEEE.
 #' @export
-check_clusterstructure <- function(x, standardize = TRUE, distance = "euclidean", ...) {
+check_clusterstructure <- function(x,
+                                   standardize = TRUE,
+                                   distance = "euclidean",
+                                   ...) {
   if (standardize) {
     x <- as.data.frame(scale(x))
   }
@@ -58,8 +75,6 @@ check_clusterstructure <- function(x, standardize = TRUE, distance = "euclidean"
 
 
 
-#' @importFrom stats heatmap
-#' @importFrom grDevices colorRampPalette
 #' @export
 plot.check_clusterstructure <- function(x, ...) {
   # Can be reimplemented with ggplot in see
@@ -73,7 +88,6 @@ plot.check_clusterstructure <- function(x, ...) {
 
 
 
-#' @importFrom stats hclust dist
 #' @keywords internal
 .clusterstructure_dm <- function(x, distance = "euclidean", method = "ward.D2") {
   d <- stats::dist(x, method = distance)
@@ -83,7 +97,6 @@ plot.check_clusterstructure <- function(x, ...) {
 
 
 
-#' @importFrom stats runif
 #' @keywords internal
 .clusterstructure_hopkins <- function(x, distance = "euclidean") {
   # This is based on the hopkins() function from the clustertend package
@@ -98,9 +111,9 @@ plot.check_clusterstructure <- function(x, ...) {
   p <- matrix(0, ncol = ncol(x), nrow = n) # n vectors of space
   for (i in 1:ncol(x))
   {
-    p[, i] <- runif(n, min = c[i], max = d[i])
+    p[, i] <- stats::runif(n, min = c[i], max = d[i])
   }
-  k <- round(runif(n, 1, nrow(x)))
+  k <- round(stats::runif(n, 1, nrow(x)))
   q <- as.matrix(x[k, ])
   distp <- rep(0, nrow(x))
   # distq=rep(0,nrow(x)-1)
@@ -109,15 +122,15 @@ plot.check_clusterstructure <- function(x, ...) {
   minq <- rep(0, n)
   for (i in 1:n)
   {
-    distp[1] <- dist(rbind(p[i, ], x[1, ]), method = distance)
-    minqi <- dist(rbind(q[i, ], x[1, ]), method = distance)
+    distp[1] <- stats::dist(rbind(p[i, ], x[1, ]), method = distance)
+    minqi <- stats::dist(rbind(q[i, ], x[1, ]), method = distance)
     for (j in 2:nrow(x))
     {
-      distp[j] <- dist(rbind(p[i, ], x[j, ]), method = distance)
+      distp[j] <- stats::dist(rbind(p[i, ], x[j, ]), method = distance)
       error <- q[i, ] - x[j, ]
       if (sum(abs(error)) != 0) {
-        # distq[j]<-dist(rbind(q[i,],x[j,]))
-        distq <- dist(rbind(q[i, ], x[j, ]), method = distance)
+        # distq[j]<-stats::dist(rbind(q[i,],x[j,]))
+        distq <- stats::dist(rbind(q[i, ], x[j, ]), method = distance)
         if (distq < minqi) {
           minqi <- distq
         }
