@@ -1,6 +1,6 @@
 
 #' @export
-ci.censReg <- ci.tobit
+model_parameters.censReg <- model_parameters.default
 
 
 #' @export
