@@ -1,9 +1,5 @@
 # .fixest -----------------------
 
-#' @export
-ci.fixest <- ci.tobit
-
-
 #' @export
 standard_error.fixest <- function(model, ...) {
   stats <- summary(model)
@@ -15,6 +11,7 @@ standard_error.fixest <- function(model, ...) {
   )
 }
 
+## TODO add ci_method later?
 
 #' @export
 p_value.fixest <- function(model, ...) {
@@ -33,10 +30,6 @@ p_value.fixest <- function(model, ...) {
 
 # .feglm -----------------------
 
-#' @export
-ci.feglm <- ci.tobit
-
-
 #' @export
 standard_error.feglm <- function(model, ...) {
   stats <- stats::coef(summary(model))
@@ -48,6 +41,7 @@ standard_error.feglm <- function(model, ...) {
   )
 }
 
+## TODO add ci_method later?
 
 #' @export
 p_value.feglm <- function(model, ...) {
