@@ -11,9 +11,8 @@ p_value.lm <- p_value.default
 
 
 #' @export
-ci.lm <- function(x, ci = .95, method = NULL, ...) {
-  robust <- !is.null(method) && method == "robust"
-  ci_wald(model = x, ci = ci, robust = robust, ...)
+ci.lm <- function(x, ci = .95, method = "residual", robust = FALSE, ...) {
+  .ci_generic(model = x, ci = ci, method = method, robust = robust, ...)
 }
 
 
@@ -48,8 +47,8 @@ p_value.summary.lm <- function(model, ...) {
 
 
 #' @export
-ci.summary.lm <- function(x, ci = .95, ...) {
-  ci_wald(model = x, ci = ci, dof = degrees_of_freedom(x), ...)
+ci.summary.lm <- function(x, ci = .95, method = "residual", ...) {
+  .ci_generic(model = x, ci = ci, method = method, dof = degrees_of_freedom(x), ...)
 }
 
 
