@@ -65,8 +65,6 @@
 
 
 #' Safe transformation from factor/character to numeric
-#'
-#' @importFrom stats na.omit
 #' @keywords internal
 .factor_to_numeric <- function(x, lowest = NULL) {
   if (is.numeric(x)) {
@@ -96,7 +94,6 @@
 
 #' Safe transformation from factor/character to numeric
 #'
-#' @importFrom stats na.omit
 #' @keywords internal
 .factor_to_dummy <- function(x) {
   if (is.numeric(x)) {
@@ -157,8 +154,7 @@
 #' for models with zero-inflation component, return required component of model-summary
 #' @keywords internal
 .filter_component <- function(dat, component) {
-  switch(
-    component,
+  switch(component,
     "conditional" = dat[dat$Component == "conditional", ],
     "zi" = ,
     "zero_inflated" = dat[dat$Component == "zero_inflated", ],
@@ -169,7 +165,6 @@
 
 
 # Find log-terms inside model formula, and return "clean" term names
-#' @importFrom insight find_terms
 .log_terms <- function(model) {
   x <- insight::find_terms(model, flatten = TRUE)
   gsub("^log\\((.*)\\)", "\\1", x[grepl("^log\\((.*)\\)", x)])
@@ -226,9 +221,11 @@
 
 
 
-#' @importFrom stats na.omit
 #' @keywords internal
 .n_unique <- function(x, na.rm = TRUE) {
+  if (is.null(x)) {
+    return(0)
+  }
   if (isTRUE(na.rm)) x <- stats::na.omit(x)
   length(unique(x))
 }
