@@ -1,6 +1,6 @@
-if (require("testthat") &&
-  require("parameters") &&
-  require("mgcv")) {
+if (requiet("testthat") &&
+  requiet("parameters") &&
+  requiet("mgcv")) {
   set.seed(123)
   dat <- gamSim(6, n = 200, scale = .2, dist = "poisson")
   m1 <-
@@ -16,7 +16,7 @@ if (require("testthat") &&
     expect_equal(
       ci(m1)$CI_low,
       c(2.361598, NA, NA, NA),
-      tolerance = 1e-4
+      tolerance = 1e-3
     )
   })
 
@@ -24,7 +24,7 @@ if (require("testthat") &&
     expect_equal(
       standard_error(m1)$SE,
       c(0.3476989, NA, NA, NA),
-      tolerance = 1e-4
+      tolerance = 1e-3
     )
   })
 
@@ -32,15 +32,32 @@ if (require("testthat") &&
     expect_equal(
       p_value(m1)$p,
       c(0, 0, 0, 0),
-      tolerance = 1e-4
+      tolerance = 1e-3
+    )
+  })
+
+  mp <- model_parameters(m1)
+  test_that("model_parameters", {
+    expect_equal(
+      mp$Coefficient,
+      c(3.0476, NA, NA, NA),
+      tolerance = 1e-3
     )
   })
 
   test_that("model_parameters", {
     expect_equal(
-      model_parameters(m1)$Coefficient,
-      c(3.0476, 3.84674, 3.17375, 8.51841),
-      tolerance = 1e-4
+      mp$df,
+      c(NA, 3.84696, 3.17389, 8.51855),
+      tolerance = 1e-3
+    )
+  })
+
+  test_that("model_parameters", {
+    expect_equal(
+      mp$df_error,
+      c(183.4606, NA, NA, NA),
+      tolerance = 1e-3
     )
   })
 }
